@@ -34,13 +34,6 @@ species[1:6,1:5]
 findSpecies("Cattle")
 
 ## ----eval=FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  novelBed <- data.frame(Chr = c(11,18,3),
-#                         Start = c(72554673, 62550672, 18148822),
-#                         End = c(72555273, 62551296, 18149488),
-#                         Gene = c("LOC1", "LOC2", "LOC3"))
-#  
-#  myFasta <- getFastaFromBed(novelBed, species = "Bos taurus",
-#                             fastaFolder = "/home/daniel/fasta/")
 #  
 
 ## ----eval=FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
@@ -218,7 +211,7 @@ knitr::include_graphics("./pigFlanking.png")
 #  +             groupColor = c("blue", "red"))
 
 ## ---- fig.retina = NULL, fig.cap="Similarity between Pig and Cow, with added coverage and annotation", echo=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-knitr::include_graphics("./coverageExample.png")
+knitr::include_graphics("./coverageExample.jpg")
 
 ## ----eval=FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  # Load the package
